@@ -3,7 +3,7 @@ use 5.014;
 # ABSTRACT: Proxy class for Mojo::UserAgent::Mockable that will not set any proxy.
 
 package Mojo::UserAgent::Mockable::Proxy;
-$Mojo::UserAgent::Mockable::Proxy::VERSION = '1.58';
+$Mojo::UserAgent::Mockable::Proxy::VERSION = '1.59';
 use Mojo::Base 'Mojo::UserAgent::Proxy';
 
 1;
@@ -23,15 +23,15 @@ Mojo::UserAgent::Mockable::Proxy - Proxy class for Mojo::UserAgent::Mockable tha
 
 =head1 VERSION
 
-version 1.58
+version 1.59
 
 =head1 AUTHOR
 
-Kit Peters <popefelix@gmail.com>
+Kit Peters <popefelix@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Kit Peters.
+This software is copyright (c) 2022 by Kit Peters.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
